#
# spec file for package dvtm
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 R. Tyler Croy <tyler@linux.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dvtm
Version:        0.15
Release:        1.31
Summary:        Tiling window manager for the console
License:        MIT
Group:          System/Console
Url:            http://www.brain-dump.org/projects/dvtm
Source0:        http://www.brain-dump.org/projects/%{name}/%{name}-%{version}.tar.gz
Patch1:         dvtm-fix_makefile.patch
BuildRequires:  ncurses-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
dvtm brings the concept of tiling window management, popularized by X11-window
managers like dwm to the console. As a console window manager it tries to make
it easy to work with multiple console based programs like vim, mutt, cmus or
irssi.

%prep
%setup -q
%patch1 -p1

%build
make %{?_smp_mflags} \
    PREFIX="%{_prefix}" \
    MANPREFIX="%{_mandir}" \
    CC="gcc" \
    OPTFLAGS="%{optflags}"

%install
make install \
    DESTDIR=%{buildroot} \
    PREFIX="%{_prefix}" \
    MANPREFIX="%{_mandir}"

%files
%defattr(-,root,root,-)
%doc LICENSE README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-status
%{_datadir}/terminfo/d/*
%{_mandir}/man1/dvtm.1%{ext_man}

%changelog
* Thu Jun  2 2016 tcech@suse.com
- update to 0.15:
  * More complicated default key bindings for potentially destructive
    actions to minimize the chance of accidental presses
  * Simplified client creation code, elimination of useless intermediate
    shell
  * Copymode coloring
  * Urgent flag indications (after a client received a bell) are redrawn
    as soon as possible.
  * Small bug fixes for terminal emulation and mouse actions
  * nmaster functionality available via MOD+{i,d} i.e. the possibility
    to change the number of windows displayed in the master area
  * "urgent flags" that is if an application issues a bell \a the
    urgent flag is set and the corresponding tag will blink
  * distinguish between return key and new line this fixes the
    behaviour of CTRL+j in certain applications
  * rudimentary support for the \e[?10{47,48,49}{h,l} xterm sequences
    to switch between alternate and normal screen buffer as used by >=
    abduco 0.3
  * better Unicode support in the statusbar
  * the current layout symbol is displayed in the tag bar
  * the position of the status/tag bar is runtime configurable via MOD+S
  * code cleanups and fixes from static analyzers
  * DragonFly BSD support
  * rewritten copy mode as an external process
  * tagging concept working the same as in dwm
  * rudimentarily sanitize $SHELL such that SHELL=dvtm dvtm is no
    longer a fork bomb.
  * more flexible key binding configuration including the possibility
    to specify key bindings involving 3 subsequent symbols.
  * unified drawing of minimized windows always on the last screen
    line.  Previously the arrangement of those minimized windows was
    done by the individual layouts.
  * use of pselect(2) instead of select(2) in order to fix a race
    condition.
  * cleanups and comments for the terminal emulation code (vt.[ch]).
    This is also in preparation for eventual use in vis.  Support for
    italic attributes and terminfo entries ({r,s}itm).  Recognize
    '\033];title\007' as title changing sequence.
  * build system (i.e config.mk) should now respect $TERMINFO and
    $PREFIX if set. By default _POSIX_C_SOURCE=200809L and
    _XOPEN_SOURCE=700 is used, if you get compile errors change them
    to match whatever your system needs to expose the required
    interfaces.
  * Solaris and AIX support (with some tweaks to config.mk)
  * fixes to the redraw logic
  * new copymode key bindings CTRL+u (page-up), CTRL+d (page-down),
    CTRL+c (quit)
  * a new layout included in the source tarball but not enabled by
    default: vstack where all windows have the full screen width
  * cleanups to the build system and manual page
  * keybindings can be defined without any modifier key as result
    config.def.h was reindented. Sorry for the resulting merge
    conflicts.
  * scroll up and down is now also bound to Shift-Page{Up,Down}
  * the window border is no longer drawn if there exists only 1
    window.
  * MOD+Tab switches to the previously focused window
  * Upon terminal resize the whole screen is completely redrawn. This
    fixes an issue with the optimized redraw logic introduced in the
    last release when attaching to an existing session with dtach or
    abduco.
  * the lock functionality (MOD-X) has been removed, use a session
    management tool like abduco to detach from your controlling
    terminal and logout properly using the existing system mechanism.
  * improved redraw logic to reduce cursor flickering
  * better non blocking input handling
  * a couple of fixes to dvtm.info terminfo description (kbs, rs1)
  * various other fixes (fd leakage, misuse of strncpy, handling of
    I/O errors)
  * copymode
  * alternate screen mode
  * dvtm now ships its own terminfo file dvtm.info (which at this time
    is mostly a copy of the previously used rxvt one) as a consequence
    $TERM within dvtm window is now set to dvtm{,-256color} depending
    on whether the "outer" terminal supports 256 color mode. The value
    of $TERM within dvtm can be overriden by the environment variable
    DVTM_TERM which will be appropriately suffixed by "-256color" if
    possible.
  * MOD+C creates a new window with the same working directory as the
    currently active window (this relies on the /proc filesystem and
    thus only works on Linux furthermore it expects a POSIX.1-2008
    conformant realpath(3) implementation).
  * -M command line flag to disable mouse support upon startup so that
    dvtm's mouse handling doesn't interfere with standard X text
    selection
  * -t command line flag to set a static title of the dvtm "root
    window" i.e.  the terminal in which dvtm itself runs. If the flag
    is omitted dvtm now sets the title to the one of the currently
    focused window.
  * dvtm now follows the config.def.h conventions of the other
    suckless projects which prevents conflicts with config.h and thus
    allows easier tracking of the git repository.
  * various terminal emulation fixes
  * various code cleanups all over the place
  * AIX support (special thanks to Ross Mohn)
  * Cygwin compile fix
  * terminal emulation correctness fixes
  * some minor code cleanups here and there
- update the spec file to meet the current standards
- rewritten dvtm-fix_makefile.patch from scratch
* Tue Sep  6 2011 pascal.bleser@opensuse.org
- update to 0.7:
  * better content backfill on window resizing
  * dynamic color changes depending on the window title
  * support for the 8 basic highlighted colors
  * rudimentary mouse support
  * fibonacci layout
* Sat Mar 12 2011 tyler@monkeypox.org
- Initial addition of a dvtm package
